Hangar CLI Documentation
========================

The CLI described below is automatically available after the Hangar Python
package has been installed (either through a package manager or via source
builds). In general, the commands require the terminals ``cwd`` to be at the
same level the repository was initially created in.

Simply start by typing ``$ hangar --help`` in your terminal to get started!

.. click:: hangar.cli:main
   :prog: hangar
   :show-nested:
